bronfmanPolynomials: Bronfman polynomials

View source: R/braids.R

bronfmanPolynomialsR Documentation

Bronfman polynomials

Description

The Bronfman polynomial of a braid group is the reciprocal of the growth function of the positive braids. This function computes the Bronfman polynomial of the braid group on n strands for n going to 1 to N.

Usage

bronfmanPolynomials(N)

Arguments

N

maximum number of strands

Value

A list of integer vectors representing the Bronfman polynomials; each vector represents the polynomial coefficients in increasing order.

Examples

bronfmanPolynomials(3) # 1, 1 - X, 1 - 2X + X^3

braids documentation built on May 29, 2024, 11:56 a.m.