| isPermutationBraid | R Documentation |
Checks whether a braid is a permutation braid, that is, a positive braid where any two strands cross at most one, and positively.
isPermutationBraid(braid)
braid |
a |
A Boolean value.
braid <- mkBraid(4, c(2, -3, 3))
isPermutationBraid(braid)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.