| bronfmanPolynomials | R Documentation |
The Bronfman polynomial of a braid group is the reciprocal of
the growth function of the positive braids. This function computes the
Bronfman polynomial of the braid group on n strands for n
going to 1 to N.
bronfmanPolynomials(N)
N |
maximum number of strands |
A list of integer vectors representing the Bronfman polynomials; each vector represents the polynomial coefficients in increasing order.
bronfmanPolynomials(3) # 1, 1 - X, 1 - 2X + X^3
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.